<?php
!defined( 'YITH_WCBK' ) && exit; // Exit if accessed directly

if ( !class_exists( 'YITH_WCBK_Admin' ) ) {
    /**
     * Class YITH_WCBK_Admin
     * handle all admin behaviors
     *
     * @author Leanza Francesco <leanzafrancesco@gmail.com>
     */
    class YITH_WCBK_Admin {

        /** @var YITH_WCBK_Admin */
        private static $_instance;

        /** @var YIT_Plugin_Panel_WooCommerce $_panel Panel object */
        private $_panel;

        /** @var string Panel page */
        private $_panel_page = 'yith_wcbk_panel';

        /** @var string Doc Url */
        public $doc_url = 'https://yithemes.com/docs-plugins/yith-woocommerce-booking/';

        /**
         * Singleton implementation
         *
         * @return YITH_WCBK_Admin
         */
        public static function get_instance() {
            return !is_null( self::$_instance ) ? self::$_instance : self::$_instance = new self();
        }

        /**
         * YITH_WCBK_Admin constructor.
         */
        private function __construct() {
            add_filter( 'admin_body_class', array( $this, 'add_classes_to_body' ) );

            add_action( 'admin_menu', array( $this, 'register_panel' ), 5 );

            // Settings Custom Tab
            add_action( 'yith_wcbk_print_global_availability_tab', array( $this, 'print_global_availability_tab' ) );
            add_action( 'yith_wcbk_print_global_costs_tab', array( $this, 'print_global_costs_tab' ) );
            add_action( 'yith_wcbk_print_integrations_tab', array( $this, 'print_integrations_tab' ) );
            add_action( 'yith_wcbk_print_google_calendar_tab', array( $this, 'print_google_calendar_tab' ) );
            add_action( 'yith_wcbk_print_logs_tab', array( $this, 'print_logs_tab' ) );

            // Add action links
            add_filter( 'plugin_action_links_' . plugin_basename( YITH_WCBK_DIR . '/' . basename( YITH_WCBK_FILE ) ), array( $this, 'action_links' ) );
            add_filter( 'plugin_row_meta', array( $this, 'plugin_row_meta' ), 10, 4 );


            YITH_WCBK_Product_Post_Type_Admin::get_instance();
            YITH_WCBK_Service_Tax_Admin::get_instance();
            YITH_WCBK_Search_Form_Post_Type_Admin::get_instance();
            YITH_WCBK_Booking_Admin::get_instance();
            YITH_WCBK_Admin_Assets::get_instance();


            // register plugin to licence/update system
            add_action( 'wp_loaded', array( $this, 'register_plugin_for_activation' ), 99 );
            add_action( 'admin_init', array( $this, 'register_plugin_for_updates' ) );
        }

        /**
         * Add classes in body
         *
         * @param string $classes
         *
         * @return string
         */
        public function add_classes_to_body( $classes ) {
            $style   = get_option( 'yith-wcbk-booking-style', 'simple' );
            $classes .= ' yith-booking-admin';
            $classes .= " yith-booking--{$style}-style ";

            return $classes;
        }

        /**
         * Action Links
         *
         * add the action links to plugin admin page
         *
         * @param $links | links plugin array
         *
         * @return  array
         * @use     plugin_action_links_{$plugin_file_name}
         */
        public function action_links( $links ) {
            $links[] = '<a href="' . admin_url( "admin.php?page={$this->_panel_page}" ) . '">' . __( 'Settings', 'yith-booking-for-woocommerce' ) . '</a>';

            return $links;
        }

        /**
         * plugin_row_meta
         *
         * add the action links to plugin admin page
         *
         * @param $plugin_meta
         * @param $plugin_file
         * @param $plugin_data
         * @param $status
         *
         * @return   array
         * @use      plugin_row_meta
         */
        public function plugin_row_meta( $plugin_meta, $plugin_file, $plugin_data, $status ) {

            if ( defined( 'YITH_WCBK_INIT' ) && YITH_WCBK_INIT == $plugin_file ) {
                $plugin_meta[] = '<a href="' . $this->doc_url . '" target="_blank">' . __( 'Plugin documentation', 'yith-booking-for-woocommerce' ) .
                                 '</a>';
            }

            return $plugin_meta;
        }

        /**
         * Print the Global availability tab
         */
        public function print_global_availability_tab() {
            include( YITH_WCBK_VIEWS_PATH . 'settings-tabs/html-global-availability.php' );
        }

        /**
         * Print the Global costs tab
         */
        public function print_global_costs_tab() {
            include( YITH_WCBK_VIEWS_PATH . 'settings-tabs/html-global-costs.php' );
        }

        /**
         * Print the Integrations tab
         */
        public function print_integrations_tab() {
            include( YITH_WCBK_VIEWS_PATH . 'settings-tabs/html-integrations.php' );
        }

        /**
         * Print the Google Calendar tab
         */
        public function print_google_calendar_tab() {
            include( YITH_WCBK_VIEWS_PATH . 'settings-tabs/html-google-calendar.php' );
        }

        /**
         * Print the Google Calendar tab
         */
        public function print_logs_tab() {
            include( YITH_WCBK_VIEWS_PATH . 'settings-tabs/html-logs.php' );
        }

        /**
         * Add a panel under YITH Plugins tab
         *
         * @return   void
         * @use      YIT_Plugin_Panel_WooCommerce class
         * @see      plugin-fw/lib/yit-plugin-panel-woocommerce.php
         */
        public function register_panel() {
            if ( !empty( $this->_panel ) ) {
                return;
            }

            $admin_tabs = array(
                'settings'        => _x( 'Settings', 'Settings tab name', 'yith-booking-for-woocommerce' ),
                'availability'    => _x( 'Availability', 'Settings tab name', 'yith-booking-for-woocommerce' ),
                'costs'           => _x( 'Costs', 'Settings tab name', 'yith-booking-for-woocommerce' ),
                'labels'          => _x( 'Labels', 'Settings tab name', 'yith-booking-for-woocommerce' ),
                'integrations'    => _x( 'Integrations', 'Settings tab name', 'yith-booking-for-woocommerce' ),
                'google-calendar' => _x( 'Google Calendar', 'Settings tab name', 'yith-booking-for-woocommerce' ),
                'logs'            => _x( 'Logs', 'Settings tab name', 'yith-booking-for-woocommerce' ),
            );

            $admin_tabs = apply_filters( 'yith_wcbk_settings_admin_tabs', $admin_tabs );

            $args = array(
                'create_menu_page' => true,
                'parent_slug'      => '',
                'page_title'       => _x( 'Booking', 'plugin name in admin page title', 'yith-booking-for-woocommerce' ),
                'menu_title'       => _x( 'Booking', 'plugin name in admin WP menu', 'yith-booking-for-woocommerce' ),
                'capability'       => 'manage_options',
                'parent'           => '',
                'parent_page'      => 'yit_plugin_panel',
                'page'             => $this->_panel_page,
                'admin-tabs'       => $admin_tabs,
                'options-path'     => YITH_WCBK_DIR . '/plugin-options',
            );

            if ( !class_exists( 'YIT_Plugin_Panel_WooCommerce' ) ) {
                require_once( '../plugin-fw/lib/yit-plugin-panel-wc.php' );
            }

            $this->_panel = new YIT_Plugin_Panel_WooCommerce( $args );
        }

        /**
         * Register plugins for activation tab
         */
        public function register_plugin_for_activation() {
            if ( !class_exists( 'YIT_Plugin_Licence' ) ) {
                require_once( YITH_WCBK_DIR . 'plugin-fw/lib/yit-plugin-licence.php' );
            }

            YIT_Plugin_Licence()->register( YITH_WCBK_INIT, YITH_WCBK_SECRET_KEY, YITH_WCBK_SLUG );
        }

        /**
         * Register plugins for update tab
         */
        public function register_plugin_for_updates() {
            if ( !class_exists( 'YIT_Upgrade' ) ) {
                require_once( YITH_WCBK_DIR . 'plugin-fw/lib/yit-upgrade.php' );
            }

            YIT_Upgrade()->register( YITH_WCBK_SLUG, YITH_WCBK_INIT );
        }
    }
}

/**
 * Unique access to instance of YITH_WCBK_Admin class
 *
 * @return YITH_WCBK_Admin
 */
function YITH_WCBK_Admin() {
    return YITH_WCBK_Admin::get_instance();
}